==> nextcloud-25.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/nb.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive til «config»-mappen!",
    "See %s" : "Se %s",
    "Sample configuration detected" : "Eksempeloppsett oppdaget",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det ble oppdaget at eksempeloppsettet er blitt kopiert. Dette kan ødelegge installasjonen din og støttes ikke. Les dokumentasjonen før du gjør endringer i config.php",
    "404" : "404",
    "%s email verification" : "%s e-postbekreftelse",
    "Email verification" : "E-postbekreftelse",
    "Click the following button to confirm your email." : "Klikk på følgende knapp for å bekrefte e-posten din.",
    "Click the following link to confirm your email." : "Klikk på følgende lenke for å bekrefte e-posten din.",
    "Confirm your email" : "Bekreft din e-post",
    "%1$s and %2$s" : "%1$s og %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
    "Education Edition" : "Utdanningsversjon",
    "Enterprise bundle" : "Bedrifts-pakke",
    "Groupware bundle" : "Gruppevare-pakke",
    "Social sharing bundle" : "Sosialdelings-pakke",
    "PHP %s or higher is required." : "PHP %s eller nyere kreves.",
    "PHP with a version lower than %s is required." : "PHP med en versjon lavere enn %s kreves.",
    "%sbit or higher PHP required." : "%sbit eller høyere PHP kreves",
    "The command line tool %s could not be found" : "Kommandolinjeverktøyet %s ble ikke funnet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgjengelig.",
    "Server version %s or higher is required." : "Serverversjon %s eller høyere kreves.",
    "Server version %s or lower is required." : "Serverversjon %s eller lavere kreves.",
    "Logged in user must be an admin" : "Innlogget bruker må være administrator",
    "Authentication" : "Autentisering",
    "Unknown filetype" : "Ukjent filtype",
    "Invalid image" : "Ugyldig bilde",
    "Avatar image is not square" : "Avatarbilde er ikke firkantet",
    "View profile" : "Vis profil",
    "today" : "i dag",
    "tomorrow" : "I morgen",
    "yesterday" : "i går",
    "_in %n day_::_in %n days_" : ["om én dag","om %n dager"],
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dager siden"],
    "next month" : "neste måned",
    "last month" : "forrige måned",
    "_in %n month_::_in %n months_" : ["neste måned","om %n måneder"],
    "_%n month ago_::_%n months ago_" : ["for %n måned siden","for %n måneder siden"],
    "next year" : "neste år",
    "last year" : "forrige år",
    "_in %n year_::_in %n years_" : ["neste år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_in %n hour_::_in %n hours_" : ["om %n time","om én timer"],
    "_%n hour ago_::_%n hours ago_" : ["for %n time siden","for %n timer siden"],
    "_in %n minute_::_in %n minutes_" : ["om ett minutt","om %n minutter"],
    "_%n minute ago_::_%n minutes ago_" : ["for %n minutt siden","for %n minutter siden"],
    "in a few seconds" : "om noen sekunder",
    "seconds ago" : "for få sekunder siden",
    "Empty file" : "Tom fil",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med ID: %s finnes ikke. Skru den på i app-innstillingene eller kontakt en administrator.",
    "File already exists" : "Filen finnes allerede",
    "Invalid path" : "Ugyldig filbane",
    "File name is a reserved word" : "Filnavnet er et reservert ord",
    "File name contains at least one invalid character" : "Filnavnet inneholder minst ett ulovlig tegn",
    "File name is too long" : "Filnavnet er for langt",
    "Dot files are not allowed" : "Punktum-filer er ikke tillatt",
    "Empty filename is not allowed" : "Tomt filnavn er ikke tillatt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres på grunn av at appinfo-filen ikke kan leses.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan ikke installeres fordi det ikke er kompatibel med denne serverversjonen.",
    "__language_name__" : "Norsk bokmål",
    "This is an automatically sent email, please do not reply." : "Dette er en automatisk sendt e-post, ikke svar.",
    "Help" : "Hjelp",
    "Apps" : "Apper",
    "Settings" : "Innstillinger",
    "Log out" : "Logg ut",
    "Users" : "Brukere",
    "Email" : "E-post",
    "Mail %s" : "E-post til %s",
    "Phone" : "Telefon",
    "Call %s" : "Ring %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Se %s på Twitter",
    "Website" : "Nettsted",
    "Visit %s" : "Besøk %s",
    "Address" : "Adresse",
    "Profile picture" : "Profilbilde",
    "About" : "Om",
    "Full name" : "Fullt navn",
    "Headline" : "Overskrift",
    "Organisation" : "Organisasion",
    "Role" : "Rolle",
    "Unknown user" : "Ukjent bruker",
    "Additional settings" : "Flere innstillinger",
    "You need to enter details of an existing account." : "Du må legge in detaljene til en eksisterende konto.",
    "Oracle connection could not be established" : "Klarte ikke å etablere forbindelse til Oracle",
    "Oracle username and/or password not valid" : "Oracle-brukernavn og/eller passord er ikke gyldig",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-brukernavn og/eller passord er ikke gyldig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X støttes ikke og %s vil ikke fungere korrekt på denne plattformen. Bruk på egen risiko!",
    "For the best results, please consider using a GNU/Linux server instead." : "For beste resultat, vurder å bruke en GNU/Linux-server i stedet.",
    "Set an admin username." : "Sett et admin-brukernavn.",
    "Set an admin password." : "Sett et admin-passord.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delings-server %s må implementere grensesnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delings-server %s ikke funnet",
    "Sharing backend for %s not found" : "Delings-server for %s ikke funnet",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med deg og vil legge til:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med deg og vil legge til",
    "»%s« added a note to a file shared with you" : "»%s« la til en melding til en fil delt med deg",
    "Open »%s«" : "Åpne »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Du har ikke lov til å dele %s",
    "Cannot increase permissions of %s" : "Kan ikke øke tillatelser for %s",
    "Expiration date is in the past" : "Utløpsdato er i fortid",
    "Sharing %s failed, because this item is already shared with user %s" : "Deling av %s mislyktes, fordi dette elementet allerede er delt med bruker %s",
    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med deg",
    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med deg.",
    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
    "The requested share does not exist anymore" : "Forespurt ressurs finnes ikke lenger",
    "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : "Ons.",
    "Thu." : "Tirs.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-'\"",
    "A valid username must be provided" : "Oppgi et gyldig brukernavn",
    "Username contains whitespace at the beginning or at the end" : "Brukernavn inneholder blanke på begynnelsen eller slutten",
    "Username must not consist of dots only" : "Brukernavn kan ikke bare bestå av punktum",
    "A valid password must be provided" : "Oppgi et gyldig passord",
    "The username is already being used" : "Brukernavnet er allerede i bruk",
    "Could not create user" : "Kunne ikke opprette bruker",
    "User disabled" : "Brukeren er deaktivert",
    "Login canceled by app" : "Innlogging avbrutt av app",
    "a safe home for all your data" : "et sikkert hjem for alle dine data",
    "File is currently busy, please try again later" : "Filen er opptatt for øyeblikket, prøv igjen senere",
    "Cannot download file" : "Kan ikke laste ned fil",
    "Application is not enabled" : "Appen er ikke aktivert",
    "Authentication error" : "Autentikasjonsfeil",
    "Token expired. Please reload page." : "Symbol utløpt. Last inn siden på nytt.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen databasedrivere (sqlite, mysql, or postgresql) installert.",
    "PHP module %s not installed." : "PHP-modul %s er ikke installert.",
    "Please ask your server administrator to install the module." : "Be server-administratoren om å installere modulen.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-innstilling \"%s\" er ikke satt til \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ved å endre denne innstillingen i php.ini gjør at Nextcloud vil kjøre igjen.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Krever minst libxml2 2.7.0. Per nå er %s installert.",
    "To fix this issue update your libxml2 version and restart your web server." : "For å fikse dette problemet, oppdater din libxml2 versjon og start webserveren på nytt.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut til at at PHP er satt opp til å fjerne innebygde doc-blokker. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av hurtiglager/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har blitt installert, men de listes fortsatt som fraværende?",
    "Please ask your server administrator to restart the web server." : "Be server-administratoren om å starte webserveren på nytt.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endre tillatelsene til 0770 slik at mappen ikke kan listes av andre brukere.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Forsikre deg om at det finnes ei fil kalt \".ocdata\" på rota av datamappa.",
    "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\".",
    "Storage unauthorized. %s" : "Lager uautorisert: %s",
    "Storage incomplete configuration. %s" : "Ikke komplett oppsett for lager. %s",
    "Storage connection error. %s" : "Tilkoblingsfeil for lager. %s",
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s",
    "%s enter the database username and name." : "%s legg inn database brukernavn og navn.",
    "%s enter the database username." : "%s legg inn brukernavn for databasen.",
    "%s enter the database name." : "%s legg inn navnet på databasen.",
    "%s you may not use dots in the database name" : "%s du kan ikke bruke punktum i databasenavnet",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ut for at %s-instansen kjører i et 32-bit PHP-miljø med open_basedir satt opp i php.ini. Dette vil føre til problemer med filer over 4 GB og frarådes på det sterkeste.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern innstillingen open_basedir i php.ini eller bytt til 64-bit PHP.",
    "Cannot read file" : "Kan ikke lese fil",
    "Cannot write into \"config\" directory" : "Kan ikke skrive i \"config\"-mappen",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dette kan vanligvis ordnes ved å gi webserveren skrivetilgang til config-mappen. Se %s",
    "Cannot write into \"apps\" directory" : "Kan ikke skrive i \"apps\"-mappen",
    "Cannot create \"data\" directory" : "Kan ikke opprette \"data\"-mappe",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Dette kan vanligvis ordnes ved å gi webserveren skrivetilgang til rotmappen. Se %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Tillatelser kan vanligvis ordnes ved å gi webserveren skrivetilgang til rotmappen. Se %s.",
    "Setting locale to %s failed" : "Setting av nasjonale innstillinger til %s mislyktes.",
    "Please install one of these locales on your system and restart your webserver." : "Installer en av disse nasjonale innstillingene på systemet ditt og start webserveren på nytt.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload er satt til \"%s\" i stedet for den forventede verdien \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Sett <code>mbstring.func_overload</code> til <code>0</code> in php.ini for å fikse dette problemet",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kreves",
    "Please upgrade your database version" : "Oppgrader databaseversjonen din",
    "Your data directory is readable by other users" : "Din datamappe kan leses av andre brukere",
    "Your data directory must be an absolute path" : "Din datamappe må være en absolutt sti",
    "Check the value of \"datadirectory\" in your configuration" : "Sjekk verdien for \"datadirectory\" i oppsettet ditt",
    "Your data directory is invalid" : "Din datamappe er ugyldig"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/nb.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive til «config»-mappen!",
    "See %s" : "Se %s",
    "Sample configuration detected" : "Eksempeloppsett oppdaget",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det ble oppdaget at eksempeloppsettet er blitt kopiert. Dette kan ødelegge installasjonen din og støttes ikke. Les dokumentasjonen før du gjør endringer i config.php",
    "404" : "404",
    "The page could not be found on the server." : "Siden ble ikke funnet på serveren.",
    "%s email verification" : "%s e-postbekreftelse",
    "Email verification" : "E-postbekreftelse",
    "Click the following button to confirm your email." : "Klikk på følgende knapp for å bekrefte e-posten din.",
    "Click the following link to confirm your email." : "Klikk på følgende lenke for å bekrefte e-posten din.",
    "Confirm your email" : "Bekreft din e-post",
    "Other activities" : "Andre aktiviteter",
    "%1$s and %2$s" : "%1$s og %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
    "Education Edition" : "Utdanningsversjon",
    "Enterprise bundle" : "Bedrifts-pakke",
    "Groupware bundle" : "Gruppevare-pakke",
    "Social sharing bundle" : "Sosialdelings-pakke",
    "PHP %s or higher is required." : "PHP %s eller nyere kreves.",
    "PHP with a version lower than %s is required." : "PHP med en versjon lavere enn %s kreves.",
    "%sbit or higher PHP required." : "%sbit eller høyere PHP kreves",
    "The command line tool %s could not be found" : "Kommandolinjeverktøyet %s ble ikke funnet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgjengelig.",
    "Server version %s or higher is required." : "Serverversjon %s eller høyere kreves.",
    "Server version %s or lower is required." : "Serverversjon %s eller lavere kreves.",
    "Logged in user must be an admin" : "Innlogget bruker må være administrator",
    "Authentication" : "Autentisering",
    "Unknown filetype" : "Ukjent filtype",
    "Invalid image" : "Ugyldig bilde",
    "Avatar image is not square" : "Avatarbilde er ikke firkantet",
    "Files" : "Filer",
    "View profile" : "Vis profil",
    "today" : "i dag",
    "tomorrow" : "I morgen",
    "yesterday" : "i går",
    "_in %n day_::_in %n days_" : ["om én dag","om %n dager"],
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dager siden"],
    "next month" : "neste måned",
    "last month" : "forrige måned",
    "_in %n month_::_in %n months_" : ["neste måned","om %n måneder"],
    "_%n month ago_::_%n months ago_" : ["for %n måned siden","for %n måneder siden"],
    "next year" : "neste år",
    "last year" : "forrige år",
    "_in %n year_::_in %n years_" : ["neste år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_in %n hour_::_in %n hours_" : ["om %n time","om én timer"],
    "_%n hour ago_::_%n hours ago_" : ["for %n time siden","for %n timer siden"],
    "_in %n minute_::_in %n minutes_" : ["om ett minutt","om %n minutter"],
    "_%n minute ago_::_%n minutes ago_" : ["for %n minutt siden","for %n minutter siden"],
    "in a few seconds" : "om noen sekunder",
    "seconds ago" : "for få sekunder siden",
    "Empty file" : "Tom fil",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med ID: %s finnes ikke. Skru den på i app-innstillingene eller kontakt en administrator.",
    "File already exists" : "Filen finnes allerede",
    "Invalid path" : "Ugyldig filbane",
    "Templates" : "Maler",
    "File name is a reserved word" : "Filnavnet er et reservert ord",
    "File name contains at least one invalid character" : "Filnavnet inneholder minst ett ulovlig tegn",
    "File name is too long" : "Filnavnet er for langt",
    "Dot files are not allowed" : "Punktum-filer er ikke tillatt",
    "Empty filename is not allowed" : "Tomt filnavn er ikke tillatt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres på grunn av at appinfo-filen ikke kan leses.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan ikke installeres fordi det ikke er kompatibel med denne serverversjonen.",
    "__language_name__" : "Norsk bokmål",
    "This is an automatically sent email, please do not reply." : "Dette er en automatisk sendt e-post, ikke svar.",
    "Help" : "Hjelp",
    "Appearance and accessibility" : "Utseende og tilgjengelighet",
    "Apps" : "Apper",
    "Personal settings" : "Personlige innstillinger",
    "Administration settings" : "Administrasjonsinnstillinger",
    "Settings" : "Innstillinger",
    "Log out" : "Logg ut",
    "Users" : "Brukere",
    "Email" : "E-post",
    "Mail %s" : "E-post til %s",
    "Phone" : "Telefon",
    "Call %s" : "Ring %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Se %s på Twitter",
    "Website" : "Nettsted",
    "Visit %s" : "Besøk %s",
    "Address" : "Adresse",
    "Profile picture" : "Profilbilde",
    "About" : "Om",
    "Headline" : "Overskrift",
    "Organisation" : "Organisasion",
    "Role" : "Rolle",
    "Unknown user" : "Ukjent bruker",
    "Additional settings" : "Flere innstillinger",
    "You need to enter details of an existing account." : "Du må legge in detaljene til en eksisterende konto.",
    "Oracle connection could not be established" : "Klarte ikke å etablere forbindelse til Oracle",
    "Oracle username and/or password not valid" : "Oracle-brukernavn og/eller passord er ikke gyldig",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-brukernavn og/eller passord er ikke gyldig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X støttes ikke og %s vil ikke fungere korrekt på denne plattformen. Bruk på egen risiko!",
    "For the best results, please consider using a GNU/Linux server instead." : "For beste resultat, vurder å bruke en GNU/Linux-server i stedet.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ut for at %s-instansen kjører i et 32-bit PHP-miljø med open_basedir satt opp i php.ini. Dette vil føre til problemer med filer over 4 GB og frarådes på det sterkeste.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern innstillingen open_basedir i php.ini eller bytt til 64-bit PHP.",
    "Set an admin username." : "Sett et admin-brukernavn.",
    "Set an admin password." : "Sett et admin-passord.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delings-server %s må implementere grensesnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delings-server %s ikke funnet",
    "Sharing backend for %s not found" : "Delings-server for %s ikke funnet",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med deg og vil legge til:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med deg og vil legge til",
    "»%s« added a note to a file shared with you" : "»%s« la til en melding til en fil delt med deg",
    "Open »%s«" : "Åpne »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Du har ikke lov til å dele %s",
    "Cannot increase permissions of %s" : "Kan ikke øke tillatelser for %s",
    "Expiration date is in the past" : "Utløpsdato er i fortid",
    "Sharing %s failed, because this item is already shared with user %s" : "Deling av %s mislyktes, fordi dette elementet allerede er delt med bruker %s",
    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med deg",
    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med deg.",
    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
    "The requested share does not exist anymore" : "Forespurt ressurs finnes ikke lenger",
    "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : "Ons.",
    "Thu." : "Tirs.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Oppgi et gyldig passord",
    "The username is already being used" : "Brukernavnet er allerede i bruk",
    "Could not create user" : "Kunne ikke opprette bruker",
    "A valid username must be provided" : "Oppgi et gyldig brukernavn",
    "Username contains whitespace at the beginning or at the end" : "Brukernavn inneholder blanke på begynnelsen eller slutten",
    "Username must not consist of dots only" : "Brukernavn kan ikke bare bestå av punktum",
    "User disabled" : "Brukeren er deaktivert",
    "Login canceled by app" : "Innlogging avbrutt av app",
    "a safe home for all your data" : "et sikkert hjem for alle dine data",
    "File is currently busy, please try again later" : "Filen er opptatt for øyeblikket, prøv igjen senere",
    "Cannot download file" : "Kan ikke laste ned fil",
    "Application is not enabled" : "Appen er ikke aktivert",
    "Authentication error" : "Autentikasjonsfeil",
    "Token expired. Please reload page." : "Symbol utløpt. Last inn siden på nytt.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen databasedrivere (sqlite, mysql, or postgresql) installert.",
    "PHP module %s not installed." : "PHP-modul %s er ikke installert.",
    "Please ask your server administrator to install the module." : "Be server-administratoren om å installere modulen.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-innstilling \"%s\" er ikke satt til \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ved å endre denne innstillingen i php.ini gjør at Nextcloud vil kjøre igjen.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Krever minst libxml2 2.7.0. Per nå er %s installert.",
    "To fix this issue update your libxml2 version and restart your web server." : "For å fikse dette problemet, oppdater din libxml2 versjon og start webserveren på nytt.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut til at at PHP er satt opp til å fjerne innebygde doc-blokker. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av hurtiglager/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har blitt installert, men de listes fortsatt som fraværende?",
    "Please ask your server administrator to restart the web server." : "Be server-administratoren om å starte webserveren på nytt.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endre tillatelsene til 0770 slik at mappen ikke kan listes av andre brukere.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Forsikre deg om at det finnes ei fil kalt \".ocdata\" på rota av datamappa.",
    "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\".",
    "Storage unauthorized. %s" : "Lager uautorisert: %s",
    "Storage incomplete configuration. %s" : "Ikke komplett oppsett for lager. %s",
    "Storage connection error. %s" : "Tilkoblingsfeil for lager. %s",
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s",
    "Full name" : "Fullt navn",
    "%s enter the database username and name." : "%s legg inn database brukernavn og navn.",
    "%s enter the database username." : "%s legg inn brukernavn for databasen.",
    "%s enter the database name." : "%s legg inn navnet på databasen.",
    "%s you may not use dots in the database name" : "%s du kan ikke bruke punktum i databasenavnet",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-'\""
},
"nplurals=2; plural=(n != 1);");
